cvts: Cross-Validation subsamples for time series

Description Usage Arguments Value Examples

View source: R/cvts.R

Description

This function takes traints and testts and create a single tibble with both results

Usage

1
cvts(data, cv_size, lead_time, ...)

Arguments

data

a dataframe with the time series data that the user wants to iterate.

cv_size

Numeric. Cross-validation window that the user want to test the performance of a model.

lead_time

Numeric. How many periods ahead (lead time) the user wants to predict.

...

Other arguments associated with traints and testts functions

Value

a tibble with rows=iterations.

Examples

1
cvts(rainfall_cr, cv_size=6, lead_time=3, keep_prev=TRUE)

opoyc/fcsttools documentation built on Feb. 19, 2020, 12:52 p.m.