Description Usage Arguments Value Examples
This function takes traints and testts and create a single tibble with both results
1 |
data |
a dataframe with the time series data that the user wants to iterate. |
cv_size |
Numeric. Cross-validation window that the user want to test the performance of a model. |
lead_time |
Numeric. How many periods ahead (lead time) the user wants to predict. |
... |
Other arguments associated with traints and testts functions |
a tibble with rows=iterations.
iteration
rest of the columns
1 | cvts(rainfall_cr, cv_size=6, lead_time=3, keep_prev=TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.